import { ManagementClientOptions, UserMfaType } from './types';
import { GraphqlClient } from '../common/GraphqlClient';
import { HttpClient } from '../common/HttpClient';
import { ManagementTokenProvider } from './ManagementTokenProvider';
/**
 * @class MFAManagementClient Manage multi-factor authentication
 * @description Used to manage users' TOTP, face and other MFA information
 *
 * @example
 *
 * Please use the module in the following ways:
 * \`\`\`javascript
 * import { ManagementClient } from "appow-js-sdk"
 * const managementClient = new ManagementClient({
 *    userPoolId: "YOUR_USERPOOL_ID",
 *    secret: "YOUR_USERPOOL_SECRET",
 * })
 * managementClient.mfa.getStatus("USER_ID") // Get user MFA binding status
 * \`\`\`
 *
 * @name MFAManagementClient
 */
export declare class MFAManagementClient {
    options: ManagementClientOptions;
    graphqlClient: GraphqlClient;
    tokenProvider: ManagementTokenProvider;
    httpClient: HttpClient;
    constructor(options: ManagementClientOptions, graphqlClient: GraphqlClient, httpClient: HttpClient, tokenProvider: ManagementTokenProvider);
    /**
     * @name getStatus
     * @name_zh Get user MFA binding status
     * @description Get user MFA binding status
     *
     * @param {string} userId 用户 ID
     *
     * @example
     *
     * const mfaStatus = await managementClient.mfa.getStatus('USER_ID');
     *
     * @memberof MFAManagementClient
     */
    getStatus(userId: string): Promise<Record<UserMfaType, boolean>>;
    /**
     * @name unAssociateMfa
     * @name_zh Unbind user MFA
     * @description Unbind user MFA
     *
     * @param {string} userId user ID
     * @param {string} type blinding type，Optional value: 'FACE', 'OTP'
     *
     * @example
     *
     * const mfaStatus = await managementClient.mfa.unAssociateMfa('USER_ID', 'FACE');
     *
     * @memberof MFAManagementClient
     */
    unAssociateMfa(userId: string, type: UserMfaType): Promise<boolean>;
}
